@@ -16,6 +16,12 @@ EOD
     __any( 'SOAP::Lite'	=> <<'EOD' ),
       This module is required for the query() method. If you do not
       intend to use this method, SOAP::Lite is not needed.
+EOD
+    __any( 'XML::DoubleEncodedEntities' => <<'EOD' ),
+      This module is not normally required. But at one point the SIMBAD
+      service was double-encoding XML entities, and anything that has
+      gone wrong once can go wrong again. If you find you need this
+      module you cam install it and it will be used.
 EOD
     __any( qw{ XML::Parser XML::Parser::Lite }	=> <<'EOD' ),
       One of these module is required to process the results of
@@ -28,65 +34,15 @@ EOD
     __none( YAML	=> '' ),
 );
 
-sub make_optional_modules_tests {
-    eval {
-	require Test::Without::Module;
-	1;
-    } or return;
-    my $dir = 'xt/author/optionals';
-    -d $dir
-	or mkdir $dir
-	or die "Can not create $dir: $!\n";
-    opendir my $dh, 't'
-	or die "Can not access t/: $!\n";
-    while ( readdir $dh ) {
-	m/ \A [.] /smx
-	    and next;
-	m/ [.] t \z /smx
-	    or next;
-	my $fn = "$dir/$_";
-	-e $fn
-	    and next;
-	print "Creating $fn\n";
-	open my $fh, '>:encoding(utf-8)', $fn
-	    or die "Can not create $fn: $!\n";
-	print { $fh } <<"EOD";
-package main;
-
-use strict;
-use warnings;
-
-use Test::More 0.88;
-
-use lib qw{ inc };
-
-use My::Module::Recommend;
-
-BEGIN {
-    eval {
-	require Test::Without::Module;
-	Test::Without::Module->import(
-	    My::Module::Recommend->optionals() );
-	1;
-    } or plan skip_all => 'Test::Without::Module not available';
-}
-
-do 't/$_';
-
-1;
-
-__END__
-
-# ex: set textwidth=72 :
-EOD
-    }
-    closedir $dh;
-
-    return $dir;
-}
+my %core = map { $_ => 1 } qw{ Time::HiRes };
 
 sub optionals {
-    return ( map { $_->modules() } @optionals );
+    # As of Test::Builder 1.302190 (March 2 2022) Time::HiRes is needed
+    # by Test::Builder, which is used by Test::More. It's a core module,
+    # so it OUGHT to be available, though there are known downstream
+    # packagers who strip core modules. Sigh. This is the reason I'm
+    # stripping it here rather than removing it completely.
+    return ( grep { ! $core{$_} } map { $_->modules() } @optionals );
 }
 
 sub recommend {
@@ -136,24 +92,6 @@ mechanism is not used because we find its output on the Draconian side.
 
 This class supports the following public methods:
 
-=head2 make_optional_modules_tests
-
- My::Module::Recommend->make_optional_modules_tests()
-
-This static method creates the optional module tests. These are stub
-files in F<xt/author/optionals/> that use C<Test::Without::Module> to
-hide all the optional modules and then invoke the normal tests in F<t/>.
-The aim of these tests is to ensure that we get no test failures if the
-optional modules are missing.
-
-This method is idempotent; that is, it only creates the directory and
-the individual stub files if they are missing.
-
-On success this method returns the name of the optional tests directory.
-If C<Test::Without::Module> can not be loaded this method returns
-nothing. If the directory or any file can not be created, an exception
-is thrown.
-
 =head2 optionals
 
  say for My::Module::Recommend->optionals();
@@ -172,7 +110,8 @@ module, and any possible problems with installing it.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://github.com/trwyant/perl-Astro-SIMBAD-Client/issues/>, or in
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-SIMBAD-Client>,
+L<https://github.com/trwyant/perl-Astro-SIMBAD-Client/issues>, or in
 electronic mail to the author.
 
 =head1 AUTHOR
@@ -181,7 +120,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013-2021 by Thomas R. Wyant, III
+Copyright (C) 2013-2022 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
