@@ -283,7 +283,6 @@ sub test_false {	## no critic (RequireArgUnpacking)
     goto &_test;
 }
 
-
 sub _test {		## no critic (RequireArgUnpacking)
     my ( $want, $title, $type ) = @_;
     $got = 'undef' unless defined $got;
@@ -516,7 +515,8 @@ comparison is done with C<is>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://github.com/trwyant/perl-Astro-SIMBAD-Client/issues/>, or in
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-SIMBAD-Client>,
+L<https://github.com/trwyant/perl-Astro-SIMBAD-Client/issues>, or in
 electronic mail to the author.
 
 =head1 AUTHOR
@@ -525,7 +525,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2021 by Thomas R. Wyant, III
+Copyright (C) 2011-2022 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
